==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarDirectiveDescriptionMetadata } from "./WebBaseToolbarDirectiveDescriptionMetadata";
import { WebBaseToolbarColumnActionsDirectiveDescription } from "./WebBaseToolbarColumnActionsDirectiveDescription";
/**
 * @hidden
 */
var WebBaseToolbarColumnActionsDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, _super);
    function WebBaseToolbarColumnActionsDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b = function (a) {
        if (WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a == null) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
        if (a.k(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c = function (a) {
        WebBaseToolbarDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:BaseToolbarColumnActionsDirective");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__skipSuffix", "Boolean");
        a.item("Name", "String");
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.d = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b(a);
        a.ad("WebBaseToolbarColumnActionsDirective", function () { return new WebBaseToolbarColumnActionsDirectiveDescription(); });
        a.ac("WebBaseToolbarColumnActionsDirective", WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.$t = markType(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, 'WebBaseToolbarColumnActionsDirectiveDescriptionMetadata');
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = null;
    return WebBaseToolbarColumnActionsDirectiveDescriptionMetadata;
}(Base));
export { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseToolbarDirectiveDescriptionMetadata } from "./WebBaseToolbarDirectiveDescriptionMetadata";
import { WebBaseToolbarColumnActionsDirectiveDescription } from "./WebBaseToolbarColumnActionsDirectiveDescription";
/**
 * @hidden
 */
var WebBaseToolbarColumnActionsDirectiveDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, _super);
    function WebBaseToolbarColumnActionsDirectiveDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b = function (a) {
        if (WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a == null) {
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
        }
        if (a.k(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.c = function (a) {
        WebBaseToolbarDirectiveDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:BaseToolbarColumnActionsDirective");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__skipSuffix", "Boolean");
        a.item("Name", "String");
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.d = function (a) {
        WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.b(a);
        a.ae("WebBaseToolbarColumnActionsDirective", function () { return new WebBaseToolbarColumnActionsDirectiveDescription(); });
        a.ad("WebBaseToolbarColumnActionsDirective", WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a);
    };
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.$t = markType(WebBaseToolbarColumnActionsDirectiveDescriptionMetadata, 'WebBaseToolbarColumnActionsDirectiveDescriptionMetadata');
    WebBaseToolbarColumnActionsDirectiveDescriptionMetadata.a = null;
    return WebBaseToolbarColumnActionsDirectiveDescriptionMetadata;
}(Base));
export { WebBaseToolbarColumnActionsDirectiveDescriptionMetadata };
